
DeNova Safelock
---------------

Locks are usually the simplest way to get safe concurrent access to a shared resource.
But they are a bear to get right.
Safelock makes it easy.
Get simple systemwide multithread, multiprocess, and multiprogram safe locks.


Full Description
----------------

Learn more about Safelock at:

    https://denova.com/open_source/safelock/
